SystemOrganization addCategory: #ConfigurationOfImageWriter!

Object subclass: #ConfigurationOfImageWriter
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfImageWriter'!

!ConfigurationOfImageWriter class methodsFor: 'private' stamp: 'GuillermoPolito 5/2/2012 16:45'!
bootstrapPackage: aString from: aPath 
	| repository version |
	repository := MCHttpRepository
				location: aPath
				user: ''
				password: ''.
	repository
		versionReaderForFileNamed: aString , '.mcz'
		do: [:reader | 
			version := reader version.
			version load.
			version workingCopy repositoryGroup addRepository: repository]! !

!ConfigurationOfImageWriter class methodsFor: 'private' stamp: 'GuillermoPolito 5/2/2012 16:45'!
ensureMetacello
        "Bootstrap Gofer (if necessary), load latest mcz file for ConfigurationOfMetacello (using old 
         Gofer API), then load the latest version of Metacello itself."

        Smalltalk at: #MetacelloProject ifAbsent: [ | error |
                "list of repositories to try, in case primary repository is not accessible"
                (Array 
                        with: 'http://www.squeaksource.com/MetacelloRepository' 
                        with: 'http://seaside.gemstone.com/ss/metacello') do: [:repositoryUrl |
                                ([
                                        Smalltalk at: #Gofer ifAbsent: [
                                        "Current version of Gofer from which to bootstrap - as of 1.0-beta.21"
                                                self bootstrapPackage: 'Gofer-Core-lr.115' from: repositoryUrl ].
                                        Smalltalk at: #Gofer ifPresent: [:goferClass | | gofer |
                                                gofer := goferClass new
                                                        url: repositoryUrl;
                                                        yourself.
                                                [ gofer addPackage: 'ConfigurationOfMetacello' ] on: Warning do: [:ex | ex resume ].
                                                gofer load ]]
                                                        on: Error
                                                        do: [ :ex |
                                                                error := ex.
                                                                Transcript 
                                                                        cr; 
                                                                        show: 'failed ensureMetacello: ';
                                                                        show: ex description printString;
                                                                        show: '...retrying'.
                                                                "try again"
                                                                ex return: nil ]) ~~ nil
                                        ifTrue: [
                                                "load 'default' group of Metacello"
                                                (Smalltalk at: #ConfigurationOfMetacello) perform: #load.
                                                ^self ]].
                "shouldn't get here unless the load failed ... throw an error"
                self error: 'retry with alternate repository failed: ', error description printString ]! !

!ConfigurationOfImageWriter class methodsFor: 'metacello tool support' stamp: 'GuillermoPolito 5/2/2012 16:45'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfImageWriter class methodsFor: 'metacello tool support' stamp: 'GuillermoPolito 5/2/2012 16:45'!
lastMetacelloVersionLoad
	"Answer the last version loaded and the list of packages loaded for that version."

	LastVersionLoad == nil ifTrue: [ LastVersionLoad := nil -> 'default' ].
	^LastVersionLoad! !

!ConfigurationOfImageWriter class methodsFor: 'metacello tool support' stamp: 'GuillermoPolito 5/2/2012 16:45'!
metacelloVersion: versionString loads: anArrayOrString
	"Stash the last version loaded and the list of packages loaded for that version. The list
	 of packages will be used by the tools when doing 'Load Package Version'"

	LastVersionLoad := versionString -> anArrayOrString! !

!ConfigurationOfImageWriter class methodsFor: 'accessing' stamp: 'GuillermoPolito 5/2/2012 16:45'!
project

	^self new project! !

!ConfigurationOfImageWriter methodsFor: 'baselines' stamp: 'GuillermoPolito 6/20/2012 11:27'!
baseline10: spec
    <version: '1.0-baseline'>
    
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://ss3.gemstone.com/ss/ImageWriter'.
	 	
		spec package: 'ImageWriter-ObjectFormats'.
		
		spec package: 'ImageWriter-Core'  with: [
	            spec requires: #('ImageWriter-ObjectFormats').
		].
	 
		spec package: 'ImageWriter-Tests' with: [
	            spec requires: #('ImageWriter-Core') ].

		spec
			group: 'default' with: #('ALL');
			group: 'Core' with: #('ImageWriter-Core')
	]! !

!ConfigurationOfImageWriter methodsFor: 'accessing' stamp: 'GuillermoPolito 5/2/2012 16:45'!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		self class ensureMetacello.
		"Construct Metacello project"
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: #linear.
		project ]! !

!ConfigurationOfImageWriter methodsFor: 'versions' stamp: 'GuillermoPolito 6/20/2012 12:04'!
stable: spec 
	<symbolicVersion: #stable>
	 
	
	spec for: #'common' version: '1.0'. 
	spec for: #'Pharo2.0.x' version: '1.2'. ! !

!ConfigurationOfImageWriter methodsFor: 'versions' stamp: 'GuillermoPolito 6/20/2012 11:26'!
version10: spec
	<version: '1.0' imports: #('1.0-baseline')>
	
	spec for: #common do: [
		spec blessing: #stable.
		spec package: 'ImageWriter-ObjectFormats' with: 'ImageWriter-ObjectFormats-GuillermoPolito.2'.
		spec package: 'ImageWriter-Core'  with: 'ImageWriter-Core-GuillermoPolito.3'.
		spec package: 'ImageWriter-Tests' with: 'ImageWriter-Tests-GuillermoPolito.1'.
		]! !

!ConfigurationOfImageWriter methodsFor: 'versions' stamp: 'GuillermoPolito 6/20/2012 11:26'!
version11: spec
	<version: '1.1' imports: #('1.0-baseline')>
	
	spec for: #common do: [
		spec blessing: #stable.
		spec package: 'ImageWriter-ObjectFormats' with: 'ImageWriter-ObjectFormats-StephaneDucasse.3'.
		spec package: 'ImageWriter-Core'  with: 'ImageWriter-Core-GuillermoPolito.11'.
		spec package: 'ImageWriter-Tests' with: 'ImageWriter-Tests-StephaneDucasse.2'.
		]! !

!ConfigurationOfImageWriter methodsFor: 'versions' stamp: 'GuillermoPolito 6/29/2012 18:23'!
version12: spec
	<version: '1.2' imports: #('1.0-baseline')>
	
	spec for: #common do: [
		spec blessing: #stable.
		spec package: 'ImageWriter-ObjectFormats' with: 'ImageWriter-ObjectFormats-StephaneDucasse.3'.
		spec package: 'ImageWriter-Core'  with: 'ImageWriter-Core-GuillermoPolito.16'.
		spec package: 'ImageWriter-Tests' with: 'ImageWriter-Tests-StephaneDucasse.2'.
		]! !
